History
=======

1.0.0 (2010-09-05)
------------------
* Featureset complete
* Public release of customshowme to PyPi
* Cleanup of project (removal of globals/locals)


0.0.5 (2010-09-05)
------------------
* @customshowme.time support (simple but big feature)
* Color output added (via vendorized Colorama)


0.0.4 (2010-09-04)
------------------
* Epic @customshowme.trace decorator written
* @customshowme.docs support


0.0.3 (2010-09-01)
------------------
* General configuration in place
* @customshowme.cputime support
* Vendorization of decorator decorator
